==> zio-aws-amplifyuibuilder_3-5.17.175.1-sources.jar: zio/aws/amplifyuibuilder/model/ExchangeCodeForTokenRequestBody.scala <==
package zio.aws.amplifyuibuilder.model
import zio.aws.amplifyuibuilder.model.primitives.SensitiveString
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class ExchangeCodeForTokenRequestBody(
    code: SensitiveString,
    redirectUri: String
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifyuibuilder.model.ExchangeCodeForTokenRequestBody = {
    import ExchangeCodeForTokenRequestBody.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifyuibuilder.model.ExchangeCodeForTokenRequestBody
      .builder()
      .code(SensitiveString.unwrap(code): java.lang.String)
      .redirectUri(redirectUri: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.amplifyuibuilder.model.ExchangeCodeForTokenRequestBody.ReadOnly =
    zio.aws.amplifyuibuilder.model.ExchangeCodeForTokenRequestBody
      .wrap(buildAwsValue())
}
object ExchangeCodeForTokenRequestBody {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifyuibuilder.model.ExchangeCodeForTokenRequestBody
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.amplifyuibuilder.model.ExchangeCodeForTokenRequestBody =
      zio.aws.amplifyuibuilder.model
        .ExchangeCodeForTokenRequestBody(code, redirectUri)
    def code: SensitiveString
    def redirectUri: String
    def getCode: ZIO[Any, Nothing, SensitiveString] = ZIO.succeed(code)
    def getRedirectUri: ZIO[Any, Nothing, String] = ZIO.succeed(redirectUri)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.ExchangeCodeForTokenRequestBody
  ) extends zio.aws.amplifyuibuilder.model.ExchangeCodeForTokenRequestBody.ReadOnly {
    override val code: SensitiveString =
      zio.aws.amplifyuibuilder.model.primitives.SensitiveString(impl.code())
    override val redirectUri: String = impl.redirectUri(): String
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.ExchangeCodeForTokenRequestBody
  ): zio.aws.amplifyuibuilder.model.ExchangeCodeForTokenRequestBody.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-amplifyuibuilder_3-6.20.162.1-sources.jar: zio/aws/amplifyuibuilder/model/ExchangeCodeForTokenRequestBody.scala <==
package zio.aws.amplifyuibuilder.model
import zio.aws.amplifyuibuilder.model.primitives.SensitiveString
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ExchangeCodeForTokenRequestBody(
    code: SensitiveString,
    redirectUri: String,
    clientId: Optional[SensitiveString] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifyuibuilder.model.ExchangeCodeForTokenRequestBody = {
    import ExchangeCodeForTokenRequestBody.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifyuibuilder.model.ExchangeCodeForTokenRequestBody
      .builder()
      .code(SensitiveString.unwrap(code): java.lang.String)
      .redirectUri(redirectUri: java.lang.String)
      .optionallyWith(
        clientId.map(value => SensitiveString.unwrap(value): java.lang.String)
      )(_.clientId)
      .build()
  }
  def asReadOnly
      : zio.aws.amplifyuibuilder.model.ExchangeCodeForTokenRequestBody.ReadOnly =
    zio.aws.amplifyuibuilder.model.ExchangeCodeForTokenRequestBody
      .wrap(buildAwsValue())
}
object ExchangeCodeForTokenRequestBody {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifyuibuilder.model.ExchangeCodeForTokenRequestBody
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.amplifyuibuilder.model.ExchangeCodeForTokenRequestBody =
      zio.aws.amplifyuibuilder.model.ExchangeCodeForTokenRequestBody(
        code,
        redirectUri,
        clientId.map(value => value)
      )
    def code: SensitiveString
    def redirectUri: String
    def clientId: Optional[SensitiveString]
    def getCode: ZIO[Any, Nothing, SensitiveString] = ZIO.succeed(code)
    def getRedirectUri: ZIO[Any, Nothing, String] = ZIO.succeed(redirectUri)
    def getClientId: ZIO[Any, AwsError, SensitiveString] =
      AwsError.unwrapOptionField("clientId", clientId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.ExchangeCodeForTokenRequestBody
  ) extends zio.aws.amplifyuibuilder.model.ExchangeCodeForTokenRequestBody.ReadOnly {
    override val code: SensitiveString =
      zio.aws.amplifyuibuilder.model.primitives.SensitiveString(impl.code())
    override val redirectUri: String = impl.redirectUri(): String
    override val clientId: Optional[SensitiveString] = zio.aws.core.internal
      .optionalFromNullable(impl.clientId())
      .map(value =>
        zio.aws.amplifyuibuilder.model.primitives.SensitiveString(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifyuibuilder.model.ExchangeCodeForTokenRequestBody
  ): zio.aws.amplifyuibuilder.model.ExchangeCodeForTokenRequestBody.ReadOnly =
    new Wrapper(impl)
}
